![](https://github.com/TheShellLand/automonisaur/raw/master/docs/images/sauruspark.gif)

# Automonisaur: Core Libraries

**[about](#about)** | 
**[pypi](https://pypi.org/project/automonisaur/)** | 
**[integrations](#integrations)** | 
**[install](#install)** | 
**[build](#build)** | 
**[unittest in docker](#unittest-in-docker')** | 
**[unittest locally](#unittest-locally)** | 
**[codecov](https://codecov.io/gh/TheShellLand/automonisaur)**


[![master](https://github.com/TheShellLand/automonisaur/actions/workflows/main.yml/badge.svg)](https://github.com/TheShellLand/automonisaur/actions)

[//]: # ([![codecov]&#40;https://codecov.io/gh/TheShellLand/automonisaur/branch/master/graph/badge.svg&#41;]&#40;https://codecov.io/gh/TheShellLand/automonisaur&#41;)



### About

This library adds some easier-to-use wrappers around common services for data
science and threat intelligence.

Provides easier clients and configuration options, as well as any additional
helpers to get things up and running.

Github issues and feature requests welcomed.


###### integrations

- airport
- elasticsearch
- flask
- minio
- neo4j
- requests
- selenium
- sentryio
- slack
- snmp
- splunk
- swift


#### install library
```shell script
/bin/bash install.sh
```

#### build docker
```shell script
/bin/bash docker/build.sh
```

#### unittest in docker
```shell script
/bin/bash docker/test.sh
```

#### unittest locally
```shell script
/bin/bash unittests.sh
```
